@@ -1,3 +1,4 @@
+require 'rbtrace'
 require 'ffi'
 
 module MsgQ
@@ -5,7 +6,7 @@ module MsgQ
   ffi_lib FFI::CURRENT_PROCESS
 
   class EventMsg < FFI::Struct
-    BUF_SIZE = RUBY_PLATFORM =~ /linux/ ? 256 : 120
+    BUF_SIZE = RBTrace::BUF_SIZE
     IPC_NOWAIT = 004000
 
     layout :mtype, :long,
