@@ -12,7 +12,7 @@ cd ..
 bundle check
 export RUBYOPT="-I.:lib"
 
-ruby server.rb &
+bundle exec ruby server.rb &
 export PID=$!
 
 trap cleanup INT TERM
@@ -23,11 +23,11 @@ cleanup() {
 
 trace() {
   echo ------------------------------------------
-  echo ./bin/rbtrace -p $PID $*
+  echo ./bin/rbtrace -p $PID "$@"
   echo ------------------------------------------
-  ./bin/rbtrace -p $PID $* &
+  bundle exec ./bin/rbtrace -p $PID "$@" &
   sleep 2
-  kill $!
+  kill $! || true
   wait $! || true
   echo
 }
@@ -37,6 +37,8 @@ trace -m sleep
 trace -m sleep Dir.chdir Dir.pwd Process.pid "String#gsub" "String#*"
 trace -m "Kernel#"
 trace -m "String#gsub(self,@test)" "String#*(self,__source__)" "String#multiply_vowels(self,self.length,num)"
+trace -e 'p(1 + 1)'
+trace -h
 trace --gc --slow=200
 trace --gc -m Dir.
 trace --slow=250
